@@ -28,22 +28,16 @@ describe 'sahara::client' do
 
   end
 
-  context 'on Debian platforms' do
-    let :facts do
-      {
-        :osfamily => 'Debian',
-        :operatingsystem => 'Debian'
-      }
-    end
+  on_supported_os({
+    :supported_os   => OSDefaults.get_supported_os
+  }).each do |os,facts|
+    context "on #{os}" do
+      let (:facts) do
+        facts.merge(OSDefaults.get_facts)
+      end
 
-    it_configures 'sahara client'
+      it_configures 'sahara client'
+    end
   end
 
-  context 'on RedHat platforms' do
-    let :facts do
-      { :osfamily => 'RedHat' }
-    end
-
-    it_configures 'sahara client'
-  end
 end
