@@ -4,6 +4,7 @@ describe 'sahara::db' do
 
   shared_examples 'sahara::db' do
     context 'with default parameters' do
+      it { is_expected.to contain_sahara_config('database/db_max_retries').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_sahara_config('database/connection').with_value('mysql+pymysql://sahara:secrete@localhost:3306/sahara').with_secret(true) }
       it { is_expected.to contain_sahara_config('database/idle_timeout').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_sahara_config('database/min_pool_size').with_value('<SERVICE DEFAULT>') }
@@ -15,7 +16,8 @@ describe 'sahara::db' do
 
     context 'with specific parameters' do
       let :params do
-        { :database_connection     => 'mysql+pymysql://sahara:sahara@localhost/sahara',
+        { :database_db_max_retries => '-1',
+          :database_connection     => 'mysql+pymysql://sahara:sahara@localhost/sahara',
           :database_idle_timeout   => '3601',
           :database_min_pool_size  => '2',
           :database_max_retries    => '11',
@@ -25,6 +27,7 @@ describe 'sahara::db' do
         }
       end
 
+      it { is_expected.to contain_sahara_config('database/db_max_retries').with_value('-1') }
       it { is_expected.to contain_sahara_config('database/connection').with_value('mysql+pymysql://sahara:sahara@localhost/sahara').with_secret(true) }
       it { is_expected.to contain_sahara_config('database/idle_timeout').with_value('3601') }
       it { is_expected.to contain_sahara_config('database/min_pool_size').with_value('2') }
@@ -70,41 +73,47 @@ describe 'sahara::db' do
     end
   end
 
-  context 'on Debian platforms' do
-    let :facts do
-      @default_facts.merge({ :osfamily => 'Debian',
-        :operatingsystem => 'Debian',
-        :operatingsystemrelease => 'jessie',
-      })
-    end
-
-    it_configures 'sahara::db'
-
+  shared_examples_for 'sahara::db on Debian' do
     context 'using pymysql driver' do
       let :params do
-        { :database_connection     => 'mysql+pymysql://sahara:sahara@localhost/sahara' }
+        { :database_connection     => 'mysql+pymysql://sahara:sahara@localhost/sahara', }
       end
 
-      it { is_expected.to contain_package('sahara-backend-package').with({ :ensure => 'present', :name => 'python-pymysql' }) }
+      it 'install the proper backend package' do
+        is_expected.to contain_package('db_backend_package').with(
+          :ensure => 'present',
+          :name   => 'python-pymysql',
+          :tag    => 'openstack'
+        )
+      end
     end
-
   end
 
-  context 'on Redhat platforms' do
-    let :facts do
-      @default_facts.merge({ :osfamily => 'RedHat',
-        :operatingsystemrelease => '7.1',
-      })
-    end
-
-    it_configures 'sahara::db'
-
+  shared_examples_for 'sahara::db on RedHat' do
     context 'using pymysql driver' do
       let :params do
-        { :database_connection     => 'mysql+pymysql://sahara:sahara@localhost/sahara' }
+        { :database_connection     => 'mysql+pymysql://sahara:sahara@localhost/sahara', }
       end
 
-      it { is_expected.not_to contain_package('sahara-backend-package') }
+      it { is_expected.not_to contain_package('db_backend_package') }
+    end
+  end
+
+  on_supported_os({
+    :supported_os   => OSDefaults.get_supported_os
+  }).each do |os,facts|
+    context "on #{os}" do
+      let (:facts) do
+        facts.merge!(OSDefaults.get_facts())
+      end
+
+      case facts[:osfamily]
+      when 'Debian'
+        it_configures 'sahara::db on Debian'
+      when 'RedHat'
+        it_configures 'sahara::db on RedHat'
+      end
+      it_configures 'sahara::db'
     end
   end
 
